@@ -1,7 +1,7 @@
 ;;; psgml.el --- SGML-editing mode with parsing support
-;; $Id: psgml.el,v 2.43 1998/11/15 19:12:34 lenst Exp $
+;; $Id: psgml.el,v 2.48 1999/10/10 13:48:38 lenst Exp $
 
-;; Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998 Lennart Staflin
+;; Copyright (C) 1993-1999 Lennart Staflin
 ;; Copyright (C) 1992 Free Software Foundation, Inc.
 
 ;; Author: Lennart Staflin <lenst@lysator.liu.se>
@@ -52,7 +52,7 @@
 
 ;;; Code:
 
-(defconst psgml-version "1.1.6"
+(defconst psgml-version "1.2.0"
   "Version of psgml package.")
 
 (defconst psgml-maintainer-address "lenst@lysator.liu.se")
@@ -601,7 +601,9 @@ See `compilation-error-regexp-alist'.")
 	     (insert
 	      "<!-- Keep this comment at the end of the file\n"
 	      "Local variables:\n"
-	      "mode: sgml\n"
+	      (if sgml-xml-p
+		  "mode: xml\n"
+		"mode: sgml\n")
 	      "End:\n"
 	      "-->\n")
 	     (forward-line -3)))
@@ -757,6 +759,7 @@ as that may change."
 	 'sgml-shorttag
 	 'sgml-namecase-general
 	 'sgml-tag-region-if-active
+         'sgml-use-text-properties
 	 ))))
 
 
@@ -1207,6 +1210,7 @@ All bindings:
   (setq sgml-always-quote-attributes t)
   (setq sgml-validate-command "nsgmls -wxml -s %s %s")
   (unless sgml-declaration
+    (make-local-variable 'sgml-declaration)
     (setq sgml-declaration sgml-xml-declaration)))
 
 (defun sgml-default-dtd-file ()
